==> estateplat-common-1.2.4-20220613.134657-1042-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxTcJcptBdcqk.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;

@Table(name = "gx_tc_jcpt_bdcqk")
public class GxTcJcptBdcqk {
    @Id
    private String ywid;
    private String bjbh;
    private String bdcqzmh;
    private String bdcqzsh;
    private String bdcdyh;
    private String zl;
    private String fwyt;
    private Double fwmj;
    private String tdyt;
    private Double tdmj;
    private String qlxz;
    private String tdsyqssj;
    private String tdsyjssj;
    private String bdcdjfj;
    private String bdcjybh;
    private String bdcjywszmh;
    private Double bdcjyjg;

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getBjbh() {
        return bjbh;
    }

    public void setBjbh(String bjbh) {
        this.bjbh = bjbh;
    }

    public String getBdcqzmh() {
        return bdcqzmh;
    }

    public void setBdcqzmh(String bdcqzmh) {
        this.bdcqzmh = bdcqzmh;
    }

    public String getBdcqzsh() {
        return bdcqzsh;
    }

    public void setBdcqzsh(String bdcqzsh) {
        this.bdcqzsh = bdcqzsh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFwyt() {
        return fwyt;
    }

    public void setFwyt(String fwyt) {
        this.fwyt = fwyt;
    }

    public Double getFwmj() {
        return fwmj;
    }

    public void setFwmj(Double fwmj) {
        this.fwmj = fwmj;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public Double getTdmj() {
        return tdmj;
    }

    public void setTdmj(Double tdmj) {
        this.tdmj = tdmj;
    }

    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }

    public String getTdsyqssj() {
        return tdsyqssj;
    }

    public void setTdsyqssj(String tdsyqssj) {
        this.tdsyqssj = tdsyqssj;
    }

    public String getTdsyjssj() {
        return tdsyjssj;
    }

    public void setTdsyjssj(String tdsyjssj) {
        this.tdsyjssj = tdsyjssj;
    }

    public String getBdcdjfj() {
        return bdcdjfj;
    }

    public void setBdcdjfj(String bdcdjfj) {
        this.bdcdjfj = bdcdjfj;
    }

    public String getBdcjybh() {
        return bdcjybh;
    }

    public void setBdcjybh(String bdcjybh) {
        this.bdcjybh = bdcjybh;
    }

    public String getBdcjywszmh() {
        return bdcjywszmh;
    }

    public void setBdcjywszmh(String bdcjywszmh) {
        this.bdcjywszmh = bdcjywszmh;
    }

    public Double getBdcjyjg() {
        return bdcjyjg;
    }

    public void setBdcjyjg(Double bdcjyjg) {
        this.bdcjyjg = bdcjyjg;
    }
}

==> estateplat-common-1.2.4-20221110.110928-1117-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxTcJcptBdcqk.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;

@Table(name = "gx_tc_jcpt_bdcqk")
public class GxTcJcptBdcqk {
    @Id
    private String ywid;
    private String bjbh;
    private String bdcqzmh;
    private String bdcqzsh;
    private String bdcdyh;
    private String zl;
    private String fwyt;
    private Double fwmj;
    private String tdyt;
    private Double tdmj;
    private String qlxz;
    private String tdsyqssj;
    private String tdsyjssj;
    private String bdcdjfj;
    private String bdcjybh;
    private String bdcjywszmh;
    private Double bdcjyjg;
    private String bz;
    private String sfdzzs;
    private String czfs;
    private String lzfs;
    private String jfqk;
    private String jkm;

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getBjbh() {
        return bjbh;
    }

    public void setBjbh(String bjbh) {
        this.bjbh = bjbh;
    }

    public String getBdcqzmh() {
        return bdcqzmh;
    }

    public void setBdcqzmh(String bdcqzmh) {
        this.bdcqzmh = bdcqzmh;
    }

    public String getBdcqzsh() {
        return bdcqzsh;
    }

    public void setBdcqzsh(String bdcqzsh) {
        this.bdcqzsh = bdcqzsh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFwyt() {
        return fwyt;
    }

    public void setFwyt(String fwyt) {
        this.fwyt = fwyt;
    }

    public Double getFwmj() {
        return fwmj;
    }

    public void setFwmj(Double fwmj) {
        this.fwmj = fwmj;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public Double getTdmj() {
        return tdmj;
    }

    public void setTdmj(Double tdmj) {
        this.tdmj = tdmj;
    }

    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }

    public String getTdsyqssj() {
        return tdsyqssj;
    }

    public void setTdsyqssj(String tdsyqssj) {
        this.tdsyqssj = tdsyqssj;
    }

    public String getTdsyjssj() {
        return tdsyjssj;
    }

    public void setTdsyjssj(String tdsyjssj) {
        this.tdsyjssj = tdsyjssj;
    }

    public String getBdcdjfj() {
        return bdcdjfj;
    }

    public void setBdcdjfj(String bdcdjfj) {
        this.bdcdjfj = bdcdjfj;
    }

    public String getBdcjybh() {
        return bdcjybh;
    }

    public void setBdcjybh(String bdcjybh) {
        this.bdcjybh = bdcjybh;
    }

    public String getBdcjywszmh() {
        return bdcjywszmh;
    }

    public void setBdcjywszmh(String bdcjywszmh) {
        this.bdcjywszmh = bdcjywszmh;
    }

    public Double getBdcjyjg() {
        return bdcjyjg;
    }

    public void setBdcjyjg(Double bdcjyjg) {
        this.bdcjyjg = bdcjyjg;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSfdzzs() {
        return sfdzzs;
    }

    public void setSfdzzs(String sfdzzs) {
        this.sfdzzs = sfdzzs;
    }

    public String getCzfs() {
        return czfs;
    }

    public void setCzfs(String czfs) {
        this.czfs = czfs;
    }

    public String getLzfs() {
        return lzfs;
    }

    public void setLzfs(String lzfs) {
        this.lzfs = lzfs;
    }

    public String getJfqk() {
        return jfqk;
    }

    public void setJfqk(String jfqk) {
        this.jfqk = jfqk;
    }

    public String getJkm() {
        return jkm;
    }

    public void setJkm(String jkm) {
        this.jkm = jkm;
    }
}
